Module cid

Module cid 

Operations about QUIC connection IDs.

Structs

ArcCidCell
Shared connection ID cell. Most of the time, you should use this struct.
ArcLocalCids
Shared local connection ID manager. Most times, you should use this struct.
ArcRemoteCids
Shared remote connection ID manager. Most of the time, you should use this struct.
BorrowedCid
A borrowed connection ID, which will be returned back when it is dropped.
ConnectionId
Connection ID in QUIC RFC 9000.
Registry
Connection ID registry.

Constants

MAX_CID_SIZE
The connection id length must not exceed 20 bytes. See ConnectionId.

Traits

GenUniqueCid
When issuing a CID to the peer, be careful not to duplicate other local connection IDs, as this will cause routing conflicts.
RetireCid
WriteConnectionId
A BufMut extension trait, makes buffer more friendly to write connection ID.

Functions

be_connection_id
Parse a connection ID from the input buffer, nom parser style.
be_connection_id_with_len
Parse a given len connection ID from the input buffer, nom parser style.