pub struct RemoveAddressFrame {
pub seq_num: VarInt,
}Expand description
REMOVE_ADDRESS Frame { Type (i) = 0x3d7e94, Sequence Number (i), }
Fields
seq_num: VarIntTrait Implementations
Sourceimpl Clone for RemoveAddressFrame
impl Clone for RemoveAddressFrame
Sourcefn clone(&self) -> RemoveAddressFrame
fn clone(&self) -> RemoveAddressFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RemoveAddressFrame
Sourceimpl Debug for RemoveAddressFrame
impl Debug for RemoveAddressFrame
Sourceimpl Deref for RemoveAddressFrame
impl Deref for RemoveAddressFrame
Sourceimpl EncodeSize for RemoveAddressFrame
impl EncodeSize for RemoveAddressFrame
Sourcefn max_encoding_size(&self) -> usize
fn max_encoding_size(&self) -> usize
Return the max number of bytes needed to encode this value Read more
Sourcefn encoding_size(&self) -> usize
fn encoding_size(&self) -> usize
Return the exact number of bytes needed to encode this value
impl Eq for RemoveAddressFrame
Sourceimpl From<RemoveAddressFrame> for ReliableFrame
impl From<RemoveAddressFrame> for ReliableFrame
Sourcefn from(v: RemoveAddressFrame) -> ReliableFrame
fn from(v: RemoveAddressFrame) -> ReliableFrame
Converts to this type from the input type.
Sourceimpl<D> From<RemoveAddressFrame> for Frame<D>
impl<D> From<RemoveAddressFrame> for Frame<D>
Sourcefn from(value: RemoveAddressFrame) -> Self
fn from(value: RemoveAddressFrame) -> Self
Converts to this type from the input type.
Sourceimpl GetFrameType for RemoveAddressFrame
impl GetFrameType for RemoveAddressFrame
Sourcefn frame_type(&self) -> FrameType
fn frame_type(&self) -> FrameType
Return the type of frame
Sourceimpl PartialEq for RemoveAddressFrame
impl PartialEq for RemoveAddressFrame
impl StructuralPartialEq for RemoveAddressFrame
Sourceimpl<D> TryFrom<Frame<D>> for RemoveAddressFrame
impl<D> TryFrom<Frame<D>> for RemoveAddressFrame
Sourceimpl TryInto<RemoveAddressFrame> for ReliableFrame
impl TryInto<RemoveAddressFrame> for ReliableFrame