Handshake

Enum Handshake 

pub enum Handshake<T>{
    Client(ClientHandshake),
    Server(ServerHandshake<T>),
}
A merged handshake state that can be used by both the client and the server.

For convenience, a unified Handshake` should be used, which will internally choose the corresponding behavior based on the role.

Variants



Client(ClientHandshake)

The client’s handshake state if the endpoint is a client.



Server(ServerHandshake<T>)

The server’s handshake state if the endpoint is a server.

Implementations

Source

impl<T> Handshake<T>

pub fn new(role: Role, output: T) -> Self

Create a new handshake state, based on the role.

pub fn new_client() -> Self

Create a new client handshake state.

pub fn new_server(output: T) -> Self

Create a new server handshake state. The output is responsible for sending the HandshakeDoneFrame to the client, see ServerHandshake::new.

pub fn is_handshake_done(&self) -> bool

Check if the handshake is complete.

pub fn done(&self) -> bool

Set the handshake status to complete(for server)

For client, this method does nothing and always returns false.

This method return true when it first time set the handshake status to complete.

pub fn role(&self) -> Role

Return the role of this handshake signal.