OneRttHeader

Struct OneRttHeader 

pub struct OneRttHeader { /* private fields */ }
A packet with a short header does not include a length, so it can only be the last packet in a UDP datagram.

     +---spin bit
     |     +---key phase bits
     |     |
+----+-----+----+------+--------------+----......---+
|1|1|S 0 0 K 0 0| DCIL | DCID(0..160) | Payload ... |
+-----+---+-+---+------+--------------+----......---+
      |<->| |<->|
        |     |
        |     +---> packet number length
        +---> reserved bits, must be 0

See 1-RTT Packet in RFC9000 for more details.

Implementations

Source

impl OneRttHeader

pub fn new(spin: SpinBit, dcid: ConnectionId) -> Self

Create a new 1RTT header.

pub fn spin(&self) -> SpinBit

Get the spin bit.