Type

Enum Type 

pub enum Type {
    Long(Type),
    Short(OneRtt),
}
The Type of the packet

The Type is only extracted from the first 3 or 4 bits of the first byte, these contents are not protected. For simplicity and future-oriented considerations, the Version of the long packet header is also considered part of the Type, such as the Initial packet of V1 version, That is, the Initial packet only makes sense under the V1 version, and it is uncertain whether future versions of QUIC will still have Initial packets. The SpinBit of the short packet header should be part of the short packet header, but for simplicity, the SpinBit is also part of the 1RTT header type.

Variants



Long(Type)



Short(OneRtt)

Implementations