pub struct PreferredAddress { /* private fields */ }Expand description
The server’s preferred address, which is used to effect a change in server address at the end of the handshake.
See section-18.2-4.31 and figure-22 for more details.
Implementations
Sourceimpl PreferredAddress
impl PreferredAddress
pub fn address_v4(&self) -> SocketAddrV4
pub fn address_v6(&self) -> SocketAddrV6
pub fn connection_id(&self) -> ConnectionId
pub fn stateless_reset_token(&self) -> ResetToken
Sourceimpl PreferredAddress
impl PreferredAddress
pub fn set_address_v4(&mut self, val: SocketAddrV4) -> &mut Self
pub fn set_address_v6(&mut self, val: SocketAddrV6) -> &mut Self
pub fn set_connection_id(&mut self, val: ConnectionId) -> &mut Self
pub fn set_stateless_reset_token(&mut self, val: ResetToken) -> &mut Self
Sourceimpl PreferredAddress
impl PreferredAddress
Sourcepub fn new(
address_v4: SocketAddrV4,
address_v6: SocketAddrV6,
connection_id: ConnectionId,
stateless_reset_token: ResetToken,
) -> Self
pub fn new( address_v4: SocketAddrV4, address_v6: SocketAddrV6, connection_id: ConnectionId, stateless_reset_token: ResetToken, ) -> Self
Create a new preferred address.
Sourcepub fn encoding_size(&self) -> usize
pub fn encoding_size(&self) -> usize
Returns the encoding size of the preferred address.