pub struct ConsistentConcurrency { /* private fields */ }Expand description
Consistent concurrency strategy increase limits as streams are closed, to keep the number of streams available to peers roughly consistent.
Implementations