pub enum Handshake<T>{
Client(ClientHandshake),
Server(ServerHandshake<T>),
}Expand description
A merged handshake state that can be used by both the client and the server.
For convenience, a unified Handshake` should be used,
which will internally choose the corresponding behavior based on the role.
Variants
Client(ClientHandshake)
The client’s handshake state if the endpoint is a client.
Server(ServerHandshake<T>)
The server’s handshake state if the endpoint is a server.
Implementations
Sourceimpl<T> Handshake<T>
impl<T> Handshake<T>
Sourcepub fn new_client() -> Self
pub fn new_client() -> Self
Create a new client handshake state.
Sourcepub fn new_server(output: T) -> Self
pub fn new_server(output: T) -> Self
Create a new server handshake state.
The output is responsible for sending the HandshakeDoneFrame to the client,
see ServerHandshake::new.
Sourcepub fn is_handshake_done(&self) -> bool
pub fn is_handshake_done(&self) -> bool
Check if the handshake is complete.