pub struct OneRttHeader { /* private fields */ }Expand description
A packet with a short header does not include a length, so it can only be the last packet in a UDP datagram.
+---spin bit
| +---key phase bits
| |
+----+-----+----+------+--------------+----......---+
|1|1|S 0 0 K 0 0| DCIL | DCID(0..160) | Payload ... |
+-----+---+-+---+------+--------------+----......---+
|<->| |<->|
| |
| +---> packet number length
+---> reserved bits, must be 0See 1-RTT Packet in RFC9000 for more details.
Implementations
Sourceimpl OneRttHeader
impl OneRttHeader